==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesGlk.php <==
<?php
/** Gilaki (گیلکی)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author AminSanaei
 * @author Varg
 */

$fallback = 'fa';

$messages = array(
'qbfind'        => 'یاتن',
'qbedit'        => 'دچین واچین',
'moredotdotdot' => 'ویشتر...',
'mypage'        => 'می هنه‌شر',
'mytalk'        => 'می گب',
'anontalk'      => 'اَ آی.پیˇ گب',

'returnto'         => 'واگرد به $1.',
'search'           => 'واموج',
'searchbutton'     => 'واموج',
'go'               => 'بوشو',
'searcharticle'    => 'بوشو',
'history_short'    => 'تارئخ',
'printableversion' => 'پرینتی نوسخه',
'permalink'        => 'مؤنسنی پیوند',
'edit'             => 'دچین واچین',
'editthispage'     => 'اَ هنه‌شره (صفحه‌یه) دچین‌واچین بکون.',
'create-this-page' => 'اَ هنه‌شره (صفحه‌یه) چاکون.',
'deletethispage'   => 'اَ هنه‌شره پاکأ کون.',
'newpage'          => 'تازه هنه‌شر (تازه صفحه)',
'talkpagelinktext' => 'گب',
'talk'             => 'گب',
'toolbox'          => 'ابزار جیگا',
'jumpto'           => 'واز بکون به:',
'jumptonavigation' => 'گردسن',
'jumptosearch'     => 'واموج',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'تازه چیؤن',
'mainpage'             => 'گت ولگ',
'mainpage-description' => 'گت ولگ',
'portal'               => 'امه جیگا',
'privacy'              => 'رازبداری',

'editsection' => 'دچین‌واچین',
'editold'     => 'دچین‌واچین',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'وانیویس (مقاله)',
'nstab-user'     => 'کاربری هنه‌شر',
'nstab-category' => 'رج',

# Search results
'searchresults'       => 'واموج‌دموجˇ نتایج',
'searchresults-title' => 'واموج‌دموجˇ نتایج، «$1»ˇ واسی',
'searchsubtitle'      => "شمه '''[[:$1]]''' ره واموتید ([[Special:Prefixindex/$1|هنه‌شرانی (صفحه‌هایی) کی «$1» همره سرأ گیفته بیدی (شوروع بیدی).]]{{int:pipe-separator}}
[[Special:WhatLinksHere/$1|او هنه‌شرانی (صفحه‌هایی) کی به «$1» خال (لینک) بدأیید]])",

# Special:AllPages
'allpagessubmit' => 'بشو',

# Special:Categories
'categories' => 'رجؤن',

# Block/unblock
'blocklink' => 'دَوَسته ببه',

# Tooltip help for the actions
'tooltip-ca-edit'    => 'شمه تانید اَ هنه‌شره (صفحه) دچین‌واچین بکونید. بی‌زحمت قبل از ان‌کی ذخیره بکونید، پیش‌نمایشˇ دوکمه جا استفاده بکونید.',
'tooltip-ca-history' => 'اَ هنه‌شر (صفحه)ˇ قدیمی نسخه‌یان',

);

==> mediawiki-1.18.5.tbz: www/mediawiki/languages/messages/MessagesGlk.php <==
<?php
/** Gilaki (گیلکی)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author AminSanaei
 * @author Varg
 * @author محک
 */

$fallback = 'fa';

$messages = array(
'moredotdotdot' => 'ویشتر...',
'mypage'        => 'می هنه‌شر',
'mytalk'        => 'می گب',
'anontalk'      => 'اَ آی.پیˇ گب',

# Cologne Blue skin
'qbfind' => 'یاتن',
'qbedit' => 'دچین واچین',

'returnto'         => 'واگرد به $1.',
'search'           => 'واموج',
'searchbutton'     => 'واموج',
'go'               => 'بوشو',
'searcharticle'    => 'بوشو',
'history_short'    => 'تارئخ',
'printableversion' => 'پرینتی نوسخه',
'permalink'        => 'مؤنسنی پیوند',
'edit'             => 'دچین واچین',
'editthispage'     => 'اَ هنه‌شره (صفحه‌یه) دچین‌واچین بکون.',
'create-this-page' => 'اَ هنه‌شره (صفحه‌یه) چاکون.',
'deletethispage'   => 'اَ هنه‌شره پاکأ کون.',
'newpage'          => 'تازه هنه‌شر (تازه صفحه)',
'talkpagelinktext' => 'گب',
'talk'             => 'گب',
'toolbox'          => 'ابزار جیگا',
'jumpto'           => 'واز بکون به:',
'jumptonavigation' => 'گردسن',
'jumptosearch'     => 'واموج',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'تازه چیؤن',
'mainpage'             => 'گت صفحه',
'mainpage-description' => 'گت صفحه',
'portal'               => 'امه جیگا',
'privacy'              => 'رازبداری',

'editsection' => 'دچین‌واچین',
'editold'     => 'دچین‌واچین',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'وانیویس (مقاله)',
'nstab-user'     => 'کاربری هنه‌شر',
'nstab-category' => 'رج',

# Search results
'searchresults'       => 'واموج‌دموجˇ نتایج',
'searchresults-title' => 'واموج‌دموجˇ نتایج، «$1»ˇ واسی',
'searchsubtitle'      => "شمه '''[[:$1]]''' ره واموتید ([[Special:Prefixindex/$1|هنه‌شرانی (صفحه‌هایی) کی «$1» همره سرأ گیفته بیدی (شوروع بیدی).]]{{int:pipe-separator}}
[[Special:WhatLinksHere/$1|او هنه‌شرانی (صفحه‌هایی) کی به «$1» خال (لینک) بدأیید]])",

# Special:AllPages
'allpagessubmit' => 'بشو',

# Special:Categories
'categories' => 'رجؤن',

'sp-contributions-talk' => 'گب',

# Block/unblock
'blocklink' => 'دَوَسته ببه',

# Tooltip help for the actions
'tooltip-ca-edit'    => 'شمه تانید اَ هنه‌شره (صفحه) دچین‌واچین بکونید. بی‌زحمت قبل از ان‌کی ذخیره بکونید، پیش‌نمایشˇ دوکمه جا استفاده بکونید.',
'tooltip-ca-history' => 'اَ هنه‌شر (صفحه)ˇ قدیمی نسخه‌یان',

);
